@@ -7,7 +7,7 @@ import xarray as xr
 
 
 def test_version():
-    assert zarrdump.__version__ == '0.1.0'
+    assert zarrdump.__version__ == '0.1.1'
 
 
 @pytest.mark.parametrize("consolidated", [True, False])
@@ -16,4 +16,4 @@ def test__open_mapper(tmpdir, consolidated):
     path = str(tmpdir.join("test.zarr"))
     ds.to_zarr(path, consolidated=consolidated)
     ds2 = _open_mapper(fsspec.get_mapper(path))
-    assert ds == ds2
\ No newline at end of file
+    xr.testing.assert_identical(ds, ds2)
\ No newline at end of file
